# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: lidar.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'lidar.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0blidar.proto\"\xd3\x05\n\x15SickScanPointCloudMsg\x12\x35\n\x06header\x18\x01 \x01(\x0b\x32%.SickScanPointCloudMsg.SickScanHeader\x12\x0e\n\x06height\x18\x02 \x01(\r\x12\r\n\x05width\x18\x03 \x01(\r\x12>\n\x06\x66ields\x18\x04 \x01(\x0b\x32..SickScanPointCloudMsg.SickScanPointFieldArray\x12\x14\n\x0cis_bigendian\x18\x05 \x01(\r\x12\x12\n\npoint_step\x18\x06 \x01(\r\x12\x10\n\x08row_step\x18\x07 \x01(\r\x12\x37\n\x04\x64\x61ta\x18\x08 \x01(\x0b\x32).SickScanPointCloudMsg.SickScanUint8Array\x12\x10\n\x08is_dense\x18\t \x01(\r\x12\x11\n\tnum_echos\x18\n \x01(\x05\x12\x13\n\x0bsegment_idx\x18\x0b \x01(\x05\x1a^\n\x0eSickScanHeader\x12\x0b\n\x03seq\x18\x01 \x01(\r\x12\x15\n\rtimestamp_sec\x18\x02 \x01(\r\x12\x16\n\x0etimestamp_nsec\x18\x03 \x01(\r\x12\x10\n\x08\x66rame_id\x18\x04 \x01(\x0c\x1aV\n\x15SickScanPointFieldMsg\x12\x0c\n\x04name\x18\x01 \x01(\x0c\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12\x10\n\x08\x64\x61tatype\x18\x03 \x01(\r\x12\r\n\x05\x63ount\x18\x04 \x01(\r\x1a\x44\n\x12SickScanUint8Array\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\x04\x12\x0c\n\x04size\x18\x02 \x01(\x04\x12\x0e\n\x06\x62uffer\x18\x03 \x01(\x0c\x1aw\n\x17SickScanPointFieldArray\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\x04\x12\x0c\n\x04size\x18\x02 \x01(\x04\x12<\n\x06\x62uffer\x18\x03 \x03(\x0b\x32,.SickScanPointCloudMsg.SickScanPointFieldMsgb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lidar_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SICKSCANPOINTCLOUDMSG']._serialized_start=16
  _globals['_SICKSCANPOINTCLOUDMSG']._serialized_end=739
  _globals['_SICKSCANPOINTCLOUDMSG_SICKSCANHEADER']._serialized_start=366
  _globals['_SICKSCANPOINTCLOUDMSG_SICKSCANHEADER']._serialized_end=460
  _globals['_SICKSCANPOINTCLOUDMSG_SICKSCANPOINTFIELDMSG']._serialized_start=462
  _globals['_SICKSCANPOINTCLOUDMSG_SICKSCANPOINTFIELDMSG']._serialized_end=548
  _globals['_SICKSCANPOINTCLOUDMSG_SICKSCANUINT8ARRAY']._serialized_start=550
  _globals['_SICKSCANPOINTCLOUDMSG_SICKSCANUINT8ARRAY']._serialized_end=618
  _globals['_SICKSCANPOINTCLOUDMSG_SICKSCANPOINTFIELDARRAY']._serialized_start=620
  _globals['_SICKSCANPOINTCLOUDMSG_SICKSCANPOINTFIELDARRAY']._serialized_end=739
# @@protoc_insertion_point(module_scope)
