"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SickScanPointCloudMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class SickScanHeader(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SEQ_FIELD_NUMBER: builtins.int
        TIMESTAMP_SEC_FIELD_NUMBER: builtins.int
        TIMESTAMP_NSEC_FIELD_NUMBER: builtins.int
        FRAME_ID_FIELD_NUMBER: builtins.int
        seq: builtins.int
        timestamp_sec: builtins.int
        timestamp_nsec: builtins.int
        frame_id: builtins.bytes
        def __init__(
            self,
            *,
            seq: builtins.int = ...,
            timestamp_sec: builtins.int = ...,
            timestamp_nsec: builtins.int = ...,
            frame_id: builtins.bytes = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["frame_id", b"frame_id", "seq", b"seq", "timestamp_nsec", b"timestamp_nsec", "timestamp_sec", b"timestamp_sec"]) -> None: ...

    @typing.final
    class SickScanPointFieldMsg(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        OFFSET_FIELD_NUMBER: builtins.int
        DATATYPE_FIELD_NUMBER: builtins.int
        COUNT_FIELD_NUMBER: builtins.int
        name: builtins.bytes
        offset: builtins.int
        datatype: builtins.int
        count: builtins.int
        def __init__(
            self,
            *,
            name: builtins.bytes = ...,
            offset: builtins.int = ...,
            datatype: builtins.int = ...,
            count: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["count", b"count", "datatype", b"datatype", "name", b"name", "offset", b"offset"]) -> None: ...

    @typing.final
    class SickScanUint8Array(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CAPACITY_FIELD_NUMBER: builtins.int
        SIZE_FIELD_NUMBER: builtins.int
        BUFFER_FIELD_NUMBER: builtins.int
        capacity: builtins.int
        size: builtins.int
        buffer: builtins.bytes
        def __init__(
            self,
            *,
            capacity: builtins.int = ...,
            size: builtins.int = ...,
            buffer: builtins.bytes = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["buffer", b"buffer", "capacity", b"capacity", "size", b"size"]) -> None: ...

    @typing.final
    class SickScanPointFieldArray(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CAPACITY_FIELD_NUMBER: builtins.int
        SIZE_FIELD_NUMBER: builtins.int
        BUFFER_FIELD_NUMBER: builtins.int
        capacity: builtins.int
        size: builtins.int
        @property
        def buffer(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SickScanPointCloudMsg.SickScanPointFieldMsg]: ...
        def __init__(
            self,
            *,
            capacity: builtins.int = ...,
            size: builtins.int = ...,
            buffer: collections.abc.Iterable[global___SickScanPointCloudMsg.SickScanPointFieldMsg] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["buffer", b"buffer", "capacity", b"capacity", "size", b"size"]) -> None: ...

    HEADER_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    FIELDS_FIELD_NUMBER: builtins.int
    IS_BIGENDIAN_FIELD_NUMBER: builtins.int
    POINT_STEP_FIELD_NUMBER: builtins.int
    ROW_STEP_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    IS_DENSE_FIELD_NUMBER: builtins.int
    NUM_ECHOS_FIELD_NUMBER: builtins.int
    SEGMENT_IDX_FIELD_NUMBER: builtins.int
    height: builtins.int
    width: builtins.int
    is_bigendian: builtins.int
    point_step: builtins.int
    row_step: builtins.int
    is_dense: builtins.int
    num_echos: builtins.int
    segment_idx: builtins.int
    @property
    def header(self) -> global___SickScanPointCloudMsg.SickScanHeader: ...
    @property
    def fields(self) -> global___SickScanPointCloudMsg.SickScanPointFieldArray: ...
    @property
    def data(self) -> global___SickScanPointCloudMsg.SickScanUint8Array: ...
    def __init__(
        self,
        *,
        header: global___SickScanPointCloudMsg.SickScanHeader | None = ...,
        height: builtins.int = ...,
        width: builtins.int = ...,
        fields: global___SickScanPointCloudMsg.SickScanPointFieldArray | None = ...,
        is_bigendian: builtins.int = ...,
        point_step: builtins.int = ...,
        row_step: builtins.int = ...,
        data: global___SickScanPointCloudMsg.SickScanUint8Array | None = ...,
        is_dense: builtins.int = ...,
        num_echos: builtins.int = ...,
        segment_idx: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "fields", b"fields", "header", b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "fields", b"fields", "header", b"header", "height", b"height", "is_bigendian", b"is_bigendian", "is_dense", b"is_dense", "num_echos", b"num_echos", "point_step", b"point_step", "row_step", b"row_step", "segment_idx", b"segment_idx", "width", b"width"]) -> None: ...

global___SickScanPointCloudMsg = SickScanPointCloudMsg
